#ifndef QPEPPERPOT_H
#define QPEPPERPOT_H
#define PLOT_HEIGHT 20
#include <QtGui/QMainWindow>
#include <qfiledialog.h>
#include <qdialog.h>
#include <qmessagebox.h>
#include <qsettings.h>
#include <qwt_plot.h>
#include <qwt_plot_curve.h>
#include <qwhatsthis.h>

#include "optionsdialog.h"
#include "projectiondialog.h"
#include "emittancedialog.h"
#include "ppdata.h"
#include <qwt3d_surfaceplot.h>
#include <qwt3d_function.h>
#include "emittancefunction.h"

namespace Ui
{
    class QPepperpot;
}
class Assistant;

class QPepperpot : public QMainWindow
{
    Q_OBJECT

public:
    QPepperpot(QWidget *parent = 0);
    ~QPepperpot();

     QSettings settings;

private:
    void setupActions();
    void writeSettings();
    void readSettings();
    bool setPixmap(const QString pixmapName);
    void setupData();
    void updateDialogBoxes();

    QPixmap m_ppPixmap;
    QString m_ppImageFileName;

    bool m_enableFindPeaks;
    bool m_enableShowPeaks;
    bool m_enableFilt;
    bool m_enableRaw;
    Assistant *assistant;

    QwtPlotCurve *m_curve;
    QwtPlotCurve *m_filteredCurve;
    QwtPlotCurve *m_peakCurve;
    Qwt3D::SurfacePlot *m_emitPlot;

    OptionsDialog *settingsDialog;
    ProjectionDialog *projectionDialog;
    EmittanceDialog *emittanceDialog;
    Ui::QPepperpot *ui_qpepperpot;

private slots:
    void fileOpen();
    void fileQuit();
    void fileSaveImage();
    void fileSaveProjection();
    void fileSaveFilteredProjection();
    void fileSaveEmittance();
    void fileSavePeaks();
    void displayAbout();
    void whatsthis();
    void optionsPreferences();
    void showProjection();
    void showEmittance();
    void showDocumentation();
    void projectionDialogDestroyed();
    void settingsDialogDestroyed();
    void emittanceDialogDestroyed();
    void toggleShowFiltered(bool on);
    void toggleShowRaw(bool on);
    void toggleShowPeaks(bool on);
    void toggleFindPeaks(bool on);
    void toggleSubtractOffset(bool on);
    void toggleEnableAOI(int state);
    void selectAOI();
    void resetAOI();

    void settingsChanged(bool apply);
    void copyToManualPeaks();
    void sortPeaks();

 protected:
    class PPData  *m_ppData;
    class PPImage *m_ppImage;


//    Qwt3D::SurfacePlot *m_emitPlot;

//    QwtPlotCurve *m_curve;
//    QwtPlotCurve *m_filteredCurve;
//    QwtPlotCurve *m_peakCurve;
};

#endif // QPEPPERPOT_H
